@@ -13,8 +13,8 @@ from .views import DictionaryConfigure
 
 urlpatterns = [
     path("configure/", DictionaryConfigure.as_view()),
-    path("configure/<str:group>", DictionaryConfigure.as_view()),
-    path("configure/<str:group>/<str:key>", DictionaryConfigure.as_view()),
+    path("configure/<str:group>/", DictionaryConfigure.as_view()),
+    path("configure/<str:group>/<str:key>/", DictionaryConfigure.as_view()),
 ]
 
 
